@@ -6,11 +6,12 @@ BEGIN {
   $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
-$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.021';
+$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.023';
 use Moose::Role;
 use namespace::autoclean;
 use File::Spec (); # core
 use Config     (); # core
+use List::Util 1.33 'any';
 
 has perlpath => (
     is      => 'ro',
@@ -18,6 +19,23 @@ has perlpath => (
     builder => 'current_perl_path',
 );
 
+has censor_commands => (
+    is => 'ro',
+    isa => 'Bool',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+
+        # look for user:password URIs
+        my ($command) = grep {
+            any { /\b\w+:[^@]+@\b/ } @{ $self->$_ }
+        } qw(run run_if_trial run_no_trial run_if_release run_no_release);
+
+        $self->log("found a $command command that looks like it contains a password: redacting this from dumped configs!") if $command;
+        $command ? 1 : 0;
+    },
+);
+
 has run => (
     is => 'ro',
     isa  => 'ArrayRef',
@@ -48,6 +66,23 @@ has run_no_release => (
     default => sub { [] },
 );
 
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        map {
+            @{$self->$_}
+            ? ( $_ => ( $self->censor_commands ? 'REDACTED' : $self->$_ ) )
+            : ()
+        }
+        qw(run run_if_trial run_no_trial run_if_release run_no_release),
+    };
+
+    return $config;
+};
+
 around BUILDARGS => sub {
     my ( $orig, $class, @args ) = @_;
     my $built = $class->$orig(@args);
@@ -133,12 +168,12 @@ sub run_cmd {
 
 around mvp_multivalue_args => sub {
     my ($original, $self) = @_;
-    
+
     my @res = $self->$original();
 
     push @res, qw( run run_no_trial run_if_trial run_if_release run_no_release );
-    
-    @res; 
+
+    @res;
 };
 
 my $path_separator = (File::Spec->catfile(qw(a b)) =~ m/^a(.+?)b$/)[0];
@@ -200,6 +235,11 @@ sub current_perl_path {
     return $perl;
 }
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This is the base role for all the plugins L<Dist::Zilla::Plugin::Run> delivers. You don't need this.
+#pod
+#pod =cut
 
 1;
 # vim: set ts=4 sts=4 sw=4 expandtab smarttab:
@@ -208,13 +248,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::Plugin::Run
 
 =head1 VERSION
 
-version 0.021
+version 0.023
 
 =head1 DESCRIPTION
 
